'\"
'\" Copyright (c) 1994-1996 Technical University of Braunschweig.
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\" 
'\" The definitions below are for supplemental macros used in Tcl/Tk
'\" manual entries.
'\"
'\" .AP type name in/out ?indent?
'\"	Start paragraph describing an argument to a library procedure.
'\"	type is type of argument (int, etc.), in/out is either "in", "out",
'\"	or "in/out" to describe whether procedure reads or modifies arg,
'\"	and indent is equivalent to second arg of .IP (shouldn't ever be
'\"	needed;  use .AS below instead)
'\"
'\" .AS ?type? ?name?
'\"	Give maximum sizes of arguments for setting tab stops.  Type and
'\"	name are examples of largest possible arguments that will be passed
'\"	to .AP later.  If args are omitted, default tab stops are used.
'\"
'\" .BS
'\"	Start box enclosure.  From here until next .BE, everything will be
'\"	enclosed in one large box.
'\"
'\" .BE
'\"	End of box enclosure.
'\"
'\" .CS
'\"	Begin code excerpt.
'\"
'\" .CE
'\"	End code excerpt.
'\"
'\" .VS ?br?
'\"	Begin vertical sidebar, for use in marking newly-changed parts
'\"	of man pages.  If an argument is present, then a line break is
'\"	forced before starting the sidebar.
'\"
'\" .VE
'\"	End of vertical sidebar.
'\"
'\" .DS
'\"	Begin an indented unfilled display.
'\"
'\" .DE
'\"	End of indented unfilled display.
'\"
'\" .SO
'\"	Start of list of standard options for a Tk widget.  The
'\"	options follow on successive lines, in four columns separated
'\"	by tabs.
'\"
'\" .SE
'\"	End of list of standard options for a Tk widget.
'\"
'\" .OP cmdName dbName dbClass
'\"	Start of description of a specific option.  cmdName gives the
'\"	option's name as specified in the class command, dbName gives
'\"	the option's name in the option database, and dbClass gives
'\"	the option's class in the option database.
'\"
'\" .UL arg1 arg2
'\"	Print arg1 underlined, then print arg2 normally.
'\"
'\" SCCS: @(#) man.macros 1.8 96/02/15 20:02:24
'\"
'\"	# Set up traps and other miscellaneous stuff for Tcl/Tk man pages.
.if t .wh -1.3i ^B
.nr ^l \n(.l
.ad b
'\"	# Start an argument description
.de AP
.ie !"\\$4"" .TP \\$4
.el \{\
.   ie !"\\$2"" .TP \\n()Cu
.   el          .TP 15
.\}
.ie !"\\$3"" \{\
.ta \\n()Au \\n()Bu
\&\\$1	\\fI\\$2\\fP	(\\$3)
.\".b
.\}
.el \{\
.br
.ie !"\\$2"" \{\
\&\\$1	\\fI\\$2\\fP
.\}
.el \{\
\&\\fI\\$1\\fP
.\}
.\}
..
'\"	# define tabbing values for .AP
.de AS
.nr )A 10n
.if !"\\$1"" .nr )A \\w'\\$1'u+3n
.nr )B \\n()Au+15n
.\"
.if !"\\$2"" .nr )B \\w'\\$2'u+\\n()Au+3n
.nr )C \\n()Bu+\\w'(in/out)'u+2n
..
.AS Tcl_Interp Tcl_CreateInterp in/out
'\"	# BS - start boxed text
'\"	# ^y = starting y location
'\"	# ^b = 1
.de BS
.br
.mk ^y
.nr ^b 1u
.if n .nf
.if n .ti 0
.if n \l'\\n(.lu\(ul'
.if n .fi
..
'\"	# BE - end boxed text (draw box now)
.de BE
.nf
.ti 0
.mk ^t
.ie n \l'\\n(^lu\(ul'
.el \{\
.\"	Draw four-sided box normally, but don't draw top of
.\"	box if the box started on an earlier page.
.ie !\\n(^b-1 \{\
\h'-1.5n'\L'|\\n(^yu-1v'\l'\\n(^lu+3n\(ul'\L'\\n(^tu+1v-\\n(^yu'\l'|0u-1.5n\(ul'
.\}
.el \}\
\h'-1.5n'\L'|\\n(^yu-1v'\h'\\n(^lu+3n'\L'\\n(^tu+1v-\\n(^yu'\l'|0u-1.5n\(ul'
.\}
.\}
.fi
.br
.nr ^b 0
..
'\"	# VS - start vertical sidebar
'\"	# ^Y = starting y location
'\"	# ^v = 1 (for troff;  for nroff this doesn't matter)
.de VS
.if !"\\$1"" .br
.mk ^Y
.ie n 'mc \s12\(br\s0
.el .nr ^v 1u
..
'\"	# VE - end of vertical sidebar
.de VE
.ie n 'mc
.el \{\
.ev 2
.nf
.ti 0
.mk ^t
\h'|\\n(^lu+3n'\L'|\\n(^Yu-1v\(bv'\v'\\n(^tu+1v-\\n(^Yu'\h'-|\\n(^lu+3n'
.sp -1
.fi
.ev
.\}
.nr ^v 0
..
'\"	# Special macro to handle page bottom:  finish off current
'\"	# box/sidebar if in box/sidebar mode, then invoked standard
'\"	# page bottom macro.
.de ^B
.ev 2
'ti 0
'nf
.mk ^t
.if \\n(^b \{\
.\"	Draw three-sided box if this is the box's first page,
.\"	draw two sides but no top otherwise.
.ie !\\n(^b-1 \h'-1.5n'\L'|\\n(^yu-1v'\l'\\n(^lu+3n\(ul'\L'\\n(^tu+1v-\\n(^yu'\h'|0u'\c
.el \h'-1.5n'\L'|\\n(^yu-1v'\h'\\n(^lu+3n'\L'\\n(^tu+1v-\\n(^yu'\h'|0u'\c
.\}
.if \\n(^v \{\
.nr ^x \\n(^tu+1v-\\n(^Yu
\kx\h'-\\nxu'\h'|\\n(^lu+3n'\ky\L'-\\n(^xu'\v'\\n(^xu'\h'|0u'\c
.\}
.bp
'fi
.ev
.if \\n(^b \{\
.mk ^y
.nr ^b 2
.\}
.if \\n(^v \{\
.mk ^Y
.\}
..
'\"	# DS - begin display
.de DS
.RS
.nf
.sp
..
'\"	# DE - end display
.de DE
.fi
.RE
.sp
..
'\"	# SO - start of list of standard options
.de SO
.SH "STANDARD OPTIONS"
.LP
.nf
.ta 4c 8c 12c
.ft B
..
'\"	# SE - end of list of standard options
.de SE
.fi
.ft R
.LP
See the \\fBoptions\\fR manual entry for details on the standard options.
..
'\"	# OP - start of full description for a single option
.de OP
.LP
.nf
.ta 4c
Command-Line Name:	\\fB\\$1\\fR
Database Name:	\\fB\\$2\\fR
Database Class:	\\fB\\$3\\fR
.fi
.IP
..
'\"	# CS - begin code excerpt
.de CS
.RS
.nf
.ta .25i .5i .75i 1i
..
'\"	# CE - end code excerpt
.de CE
.fi
.RE
..
.de UL
\\$1\l'|0\(ul'\\$2
..
.TH http n "" Tnm "Tnm Tcl Extension"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
http \- Send and process HTTP requests.
.BE

.SH DESCRIPTION

The Hypertext Transfer Protocol (HTTP) (RFC 1945) is a client/server
protocol used to retrieve documents in the World Wide Web. Documents
are addressed using Uniform Resource Locators (URL) (RFC 1738). The
\fBhttp\fR command allows to implement HTTP clients and a simple HTTP
server.

.SH HTTP COMMAND
The following list of http commands is useful for HTTP clients:
.TP
.B http proxy \fR[\fIurl\fR]
The \fBhttp proxy\fR command allows to define a proxy HTTP server
which will be used in subsequent client commands. Using this command
without an \fIurl\fR argument will return the URL to the currently
used proxy or an empty string. Providing a \fIurl\fR argument sets the
proxy server.  Setting the proxy to an empty string turns the proxy
feature off.
.TP
.B http head \fIurl\fR
The \fBhttp head\fR command retrieves the HTTP header for the document
located at \fIurl\fR. The header is returned as a list of keys and
values which can be converted into a Tcl array using the array set
command.
.TP
.B http get \fIurl\fR \fIfileName\fR
The \fBhttp get\fR command retrieves the document located at
\fIurl\fR. The body of the document is written to the file named
\fIfileName\fR. The command returns the HTTP header as described for
the \fBhttp head\fR command above.
.TP
.B http post \fIurl\fR \fIdocFileName\fR \fIfileName\fR
The \fBhttp post\fR command posts the document in \fIdocFileName\fR to
the location \fIurl\fR. The body of the returned document is written
to the file named \fIfileName\fR. The command returns the HTTP header
as described for the \fBhttp head\fR command above.
.TP
.B http put \fIurl\fR \fIdocFileName\fR
The \fBhttp put\fR command puts the document in \fIdocFileName\fR to
the location \fIurl\fR. The command returns the HTTP header as
described for the \fBhttp head\fR command above.
.TP
.B http delete \fIurl\fR
The \fBhttp delete\fR command deletes the document at the location
defined by \fIurl\fR. The command returns HTTP status information.
.PP
The following set of http commands is useful for a simple HTTP server:
.TP
.B http server \fR[\fIport\fR]
The \fBhttp server\fR command starts a simple HTTP server listening on
port \fIport\fR. If called without a \fIport\fR argument, the
currently used port number or an empty string is returned. An empty
string indicates that no server is currently active.
.TP
.B http mime \fItype\fR \fIextension\fR
The \fBhttp mime\fR command is used to add mime type definitions to
the internal table which maps file name extension to mime types. If
called without an argument, the list of all mime type mappings is
returned. A new mapping is created by supplying a mime \fItype\fR and
the file name \fIextension\fR.
.TP
.B http bind \fIpattern\fR \fImethod\fR \fR[\fIscript\fR]

The \fBhttp bind\fR command binds a Tcl script to the invocation of a
HTTP \fImethod\fR where the URL matches \fIpattern\fR. Whenever a HTTP
request of type \fImethod\fR is received that matches the pattern,
\fIscript\fR is evaluated. The return value of the script must be a
name of a file which will be send back to the client. Errors during
the evaluation of the \fIscript\fR will result in an error response.

The following % sequences are substituted before a script bound
to a URL is evaluated:
.RS
.TP 6
.B %A
The network address of the client.
.TP
.B %P
The URL path requested by the client.
.TP
.B %S
The search path contained in the URL path.
.RE

.SH SEE ALSO
scotty(1), Tnm(n), Tcl(n)

.SH AUTHORS
Juergen Schoenwaelder <schoenw@cs.utwente.nl>
.br
